@@ -4,6 +4,11 @@ from enum import Enum
 
 from pipeline_telemetry.settings.data_class import ProcessType
 
+TRAFIC_LIGHT_COLOR_GREEN = 'GREEN'
+TRAFIC_LIGHT_COLOR_ORANGE = 'ORANGE'
+TRAFIC_LIGHT_COLOR_RED = 'RED'
+DEFAULT_TRAFIC_LIGHT_COLOR = TRAFIC_LIGHT_COLOR_GREEN
+
 DEFAULT_CREATE_DATA_SUB_PROCESS_TYPES = [
     "RETRIEVE_RAW_DATA",
     "DATA_CONVERSION",
